<div align="center">
  <img src="./logo.png" alt="nipcat Logo" width="200">
  <h1>NipCat</h1>
  <p>TCP/IP Swiss Army Knife</p>
  <a href="https://github.com/walidsa3d/actions/workflows/test.yml">
    <img src="https://img.shields.io/github/actions/workflow/status/walidsa3d/nipcat/test.yml?branch=main&style=flat-square" alt="Test Status">
  </a>
  <a href="https://github.com/walidsa3d/nipcat/blob/main/LICENSE">
    <img src="https://img.shields.io/github/license/walidsa3d/nipcat?style=flat-square" alt="License">
  </a>
</div>

NipCat is a TCP/IP Swiss Army Knife.

## 🚀 Features


## Installation
```
pip install nipcat
```

## Usage
```
nipcat -i
nipcat 192.168.0.1/22
```

## 🧑‍💻 Contributing

Contributions are welcome! Please feel free to submit a Pull Request.

## 📄 License
This project is licensed under the MIT License. See the LICENSE file for more details.


